Members are the actual IP addresses that will receive traffic from the load balancer. Each member must have a unique combination of IP address and port.

The Available Instances table contains existing compute instances that can be added as members of the pool. Use the "Add external member" button to add a member not found in the Available Instances table.

IP address: The IP address of the member to receive traffic from the load balancer. Must be a well-formed IPv4 or IPv6 address.

Subnet: The network which contains the IP address of the member.

Port: The port on which the member listens for traffic. Must be a number from 1 to 65535.

Weight: The weight of a member determines the portion of requests or connections it services compared to the other members of the pool. A higher weight means it will receive more traffic. Must be a number from 1 to 256.

Monitor Address: An alternate IP address used for health monitoring a backend member. Default is null which monitors the member address.

Monitor Port: An alternate protocol port used for health monitoring a backend member. Default is null which monitors the member protocol port.

Backup: Is the member a backup? Backup members only receive traffic when all non-backup members are down.